
# Slot: expressed in


holds between a gene or gene product and an anatomical entity in which it is expressed

URI: [biolink:expressed_in](https://w3id.org/biolink/vocab/expressed_in)


## Domain and Range

[GeneOrGeneProduct](GeneOrGeneProduct.md) &#8594;  <sub>0..\*</sub> [AnatomicalEntity](AnatomicalEntity.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | RO:0002206 |
| **Narrow Mappings:** | | NCIT:R49 |
|  | | NCIT:R46 |
|  | | RTXKG1:expressed_in |

